.. currentmodule:: sardana.macroserver.msexception

:mod:`~sardana.macroserver.msexception`
=========================================

.. automodule:: sardana.macroserver.msexception

.. rubric:: Functions

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`MacroServerException`

MacroServerException
--------------------

.. autoclass:: MacroServerException
    :show-inheritance:
